from bluer_objects.README.items import ImageItems

docs = [
    {
        "path": "../docs/UGVs",
    },
    {
        "path": "../docs/UGVs/swallow.md",
        "items": ImageItems(
            {
                "https://github.com/kamangir/assets2/raw/main/bluer-swallow/20250701_2206342_1.gif?raw=true": "",
                "https://github.com/kamangir/assets2/raw/main/bluer-swallow/20250913_203635~2_1.gif?raw=true": "",
            }
        ),
    },
    {
        "path": "../docs/UGVs/sparrow.md",
        "items": ImageItems(
            {
                "https://github.com/kamangir/assets2/raw/main/bluer-sparrow/VID-20250905-WA0014_1.gif?raw=true": "",
            }
        ),
    },
    {
        "path": "../docs/UGVs/sparrow2.md",
        "items": ImageItems(
            {
                "https://github.com/kamangir/assets2/raw/main/bluer-sparrow/VID-20250905-WA0014_1.gif?raw=true": "",
            }
        ),
    },
    {
        "path": "../docs/UGVs/sparrow3.md",
        "items": ImageItems(
            {
                "https://github.com/kamangir/assets/blob/main/bluer-ugv/bluer-light.png?raw=true": ""
            }
        ),
    },
    {
        "path": "../docs/UGVs/sparrow4.md",
        "items": ImageItems(
            {
                "https://github.com/kamangir/assets/blob/main/bluer-ugv/bluer-light.png?raw=true": ""
            }
        ),
    },
]
